@@ -18,6 +18,7 @@ from .utils import (
     make_relative_time_property,
     make_openid_identifier_property,
 )
+import notifications
 
 from tahrir_api.dbapi import TahrirDatabase
 import tahrir_api.model
@@ -36,6 +37,8 @@ def main(global_config, **settings):
     tahrir_api.model.Person.avatar_url = make_avatar_method(cache)
     tahrir_api.model.Person.email_md5 = property(
         lambda self: hashlib.md5(self.email).hexdigest())
+    tahrir_api.model.Person.email_sha1 = property(
+        lambda self: hashlib.sha1(self.email).hexdigest())
 
     identifier = settings.get('tahrir.openid_identifier')
     tahrir_api.model.Person.openid_identifier =\
@@ -58,7 +61,8 @@ def main(global_config, **settings):
             calling anywhere.
         """
         session = session_cls()
-        return TahrirDatabase(session=session, autocommit=False)
+        return TahrirDatabase(session=session, autocommit=False,
+                              notification_callback=notifications.callback)
 
     required_keys = [
         'tahrir.pngs.uri',
@@ -97,10 +101,14 @@ def main(global_config, **settings):
         callback=groupfinder, # groupfinder callback checks for admin privs
         hashalg='sha512', # because md5 is deprecated
         secure=asbool(settings['tahrir.secure_cookies']),
+        http_only=asbool(settings['tahrir.httponly_cookies']),
     )
     authz_policy = ACLAuthorizationPolicy()
     session_factory = UnencryptedCookieSessionFactoryConfig(
-            settings['session.secret'])
+        secret=settings['session.secret'],
+        cookie_secure=asbool(settings['tahrir.secure_cookies']),
+        cookie_httponly=asbool(settings['tahrir.httponly_cookies']),
+    )
 
     # Configure our cache that we instantiated earlier.
     cache.configure_from_config(settings, 'dogpile.cache.')
@@ -112,14 +120,21 @@ def main(global_config, **settings):
             authentication_policy=authn_policy,
             authorization_policy=authz_policy)
 
+    import tahrir.custom_openid
     config.include('velruse.providers.openid')
-    config.add_openid_login(realm=settings.get('tahrir.openid_realm'))
+    tahrir.custom_openid.add_openid_login(
+        config,
+        realm=settings.get('tahrir.openid_realm'),
+        identity_provider=settings.get('tahrir.openid_identifier'),
+    )
+
+    config.include('pyramid_mako')
 
     config.add_request_method(get_db, 'db', reify=True)
 
     config.add_static_view(
         'static',
-        settings.get('tahrir.static.uri', 'static'),
+        settings.get('tahrir.theme_name', 'tahrir') + ':static',
         cache_max_age=3600,
     )
     config.add_static_view(
@@ -129,20 +144,46 @@ def main(global_config, **settings):
     )
 
     config.add_route('home', '/')
+    config.add_route('heartbeat', '/heartbeat')
+
+    # main admin endpoint
     config.add_route('admin', '/admin')
+
+    # delegated admin endpoints
+    config.add_route('award', '/award')
+    config.add_route('invite', '/invite')
+    config.add_route('add_tag', '/add_tag')
+
     config.add_route('qrcode', '/qrcode')
     config.add_route('badge', '/badge/{id}')
+    config.add_route('badge_full', '/badge/{id}/full')
     config.add_route('badge_json', '/badge/{id}/json')
+    config.add_route('badge_rss', '/badge/{id}/rss')
+    config.add_route('badge_stl', '/badge/{id}/stl')
     config.add_route('builder', '/builder')
     config.add_route('about', '/about')
     config.add_route('explore', '/explore')
     config.add_route('explore_badges', '/explore/badges')
+    config.add_route('explore_badges_rss', '/explore/badges/rss')
     config.add_route('leaderboard', '/leaderboard')
     config.add_route('leaderboard_json', '/leaderboard/json')
     config.add_route('rank_json', '/leaderboard/{id}/json')
     config.add_route('tags', '/tags/{tags}/{match}')
     config.add_route('user', '/user/{id}')
+    config.add_route('user_edit', '/user/{id}/edit')
     config.add_route('user_json', '/user/{id}/json')
+    config.add_route('user_rss', '/user/{id}/rss')
+    config.add_route('user_foaf', '/user/{id}/foaf')
+    config.add_route('diff', '/diff/{id_a}/{id_b}')
+    config.add_route('report', '/report')
+    config.add_route('report_this_month', '/report/this/month')
+    config.add_route('report_year', '/report/{year}')
+    config.add_route('report_year_month', '/report/{year}/{month}')
+    config.add_route('report_year_week',
+                     '/report/{year}/week/{weeknumber}')
+    config.add_route('report_year_month_day',
+                     '/report/{year}/{month}/{day}')
+    config.add_route('award_from_csv', '/award_from_csv')
     config.add_route('login', '/login')
     config.add_route('logout', '/logout')
 
