@@ -5,6 +5,7 @@ from pyramid.events import (
 
 from pyramid.security import (
     authenticated_userid,
+    effective_principals,
 )
 
 from pyramid.settings import asbool
@@ -13,6 +14,8 @@ import tw2.jquery
 
 import tahrir.views
 
+from pkg_resources import get_distribution
+
 
 @subscriber(BeforeRender)
 def inject_globals(event):
@@ -30,10 +33,14 @@ def inject_globals(event):
     # dict returned by the view every time!
     event['title'] = settings['tahrir.title']
     event['base_url'] = settings['tahrir.base_url']
+    event['theme_name'] = settings.get('tahrir.theme_name', 'tahrir')
+
+    event['tahrir_version'] = get_distribution('tahrir').version
+    event['tahrir_api_version'] = get_distribution('tahrir-api').version
 
     event['logged_in'] = authenticated_userid(request)
     person = request.db.get_person(event['logged_in'])
-    event['logged_in_id'] = getattr(person, 'id', None)
+    event['logged_in_person'] = person
 
     event['footer'] = tahrir.views.load_docs(request, 'footer')
 
@@ -44,5 +51,7 @@ def inject_globals(event):
         'tahrir.social.twitter_user_hash')
     event['gplus'] = asbool(settings.get('tahrir.social.gplus'))
 
+    event['auth_principals'] = effective_principals(request)
+
     # Cause jquery.js to be injected into the page.
     tw2.jquery.jquery_js.display()
