@@ -90,8 +90,9 @@ def make_avatar_method(cache):
     @cache.cache_on_arguments()
     def _avatar_function(email, size):
         request = pyramid.threadlocal.get_current_request()
-        absolute_default = request.static_url(
-            'tahrir:static/img/badger_avatar.png')
+        absolute_default = request.registry.settings.get(
+            'tahrir.default_avatar',
+            'https://badges.fedoraproject.org/static/img/badger_avatar.png')
 
         query = {
             's': size,
@@ -126,8 +127,12 @@ def make_avatar_method(cache):
             return gravatar_url
 
     def avatar_method(self, size):
+        # dogpile.cache can barf on unicode, so do this ourselves.
+        ident = self.openid_identifier
+        if isinstance(ident, unicode):
+            ident = ident.encode('utf-8')
         # Call the cached workhorse function
-        return _avatar_function(self.openid_identifier, size)
+        return _avatar_function(ident, size)
 
     return avatar_method
 
@@ -153,7 +158,7 @@ def make_relative_time_property(attr):
     @property
     def relative_time_method(self):
         then_in_seconds = time.mktime(getattr(self, attr).timetuple())
-        now_in_seconds = time.mktime(datetime.datetime.now().timetuple())
+        now_in_seconds = time.mktime(datetime.datetime.utcnow().timetuple())
         delta = now_in_seconds - then_in_seconds
 
         if delta > 0:
